==> fastyle_dart-1.0.0.tar.gz: lib/ui/widgets/lists/navigation_list_item.widget.dart <==
import 'package:fastyle_dart/fastyle_dart.dart';
import 'package:flutter/material.dart';

class FastNavigationListItem<T extends FastItem> extends StatelessWidget {
  final EdgeInsets? contentPadding;

  ///
  /// Allow to convert the label to beginning of sentence case.
  ///
  final bool capitalizeLabelText;
  final String? descriptionText;
  final VoidCallback onTap;
  final String? labelText;
  final Widget? leading;
  final Widget trailing;
  final bool isEnabled;
  final bool isDense;
  final T? item;
  final bool showTrailing;
  final bool showLeading;

  FastNavigationListItem({
    Key? key,
    required this.onTap,
    this.trailing = kFastNavigationTrailingIcon,
    this.capitalizeLabelText = true,
    this.isEnabled = true,
    this.isDense = true,
    this.showTrailing = true,
    this.showLeading = true,
    this.descriptionText,
    this.contentPadding,
    this.labelText,
    this.leading,
    this.item,
  })  : assert(item != null || labelText != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return FastListItemLayout(
      trailing: showTrailing ? item?.descriptor?.trailing ?? trailing : null,
      leading: showLeading ? item?.descriptor?.leading ?? leading : null,
      descriptionText: item?.descriptionText ?? descriptionText,
      isDense: item?.descriptor?.isDense ?? isDense,
      labelText: item?.labelText ?? labelText!,
      capitalizeLabelText: capitalizeLabelText,
      isEnabled: item?.isEnabled ?? isEnabled,
      contentPadding: contentPadding,
      onTap: onTap,
    );
  }
}

==> fastyle_dart-1.0.4.tar.gz: lib/ui/widgets/lists/navigation_list_item.widget.dart <==
import 'package:fastyle_dart/fastyle_dart.dart';
import 'package:flutter/material.dart';

class FastNavigationListItem<T extends FastItem> extends StatelessWidget {
  final EdgeInsets? contentPadding;

  ///
  /// Allow to convert the label to beginning of sentence case.
  ///
  final bool capitalizeLabelText;
  final String? descriptionText;
  final VoidCallback onTap;
  final String? labelText;
  final Widget? leading;
  final Widget trailing;
  final bool isEnabled;
  final bool isDense;
  final T? item;
  final bool showTrailing;
  final bool showLeading;

  const FastNavigationListItem({
    Key? key,
    required this.onTap,
    this.trailing = kFastNavigationTrailingIcon,
    this.capitalizeLabelText = true,
    this.isEnabled = true,
    this.isDense = true,
    this.showTrailing = true,
    this.showLeading = true,
    this.descriptionText,
    this.contentPadding,
    this.labelText,
    this.leading,
    this.item,
  })  : assert(item != null || labelText != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return FastListItemLayout(
      trailing: showTrailing ? item?.descriptor?.trailing ?? trailing : null,
      leading: showLeading ? item?.descriptor?.leading ?? leading : null,
      descriptionText: item?.descriptionText ?? descriptionText,
      isDense: item?.descriptor?.isDense ?? isDense,
      labelText: item?.labelText ?? labelText!,
      capitalizeLabelText: capitalizeLabelText,
      isEnabled: item?.isEnabled ?? isEnabled,
      contentPadding: contentPadding,
      onTap: onTap,
    );
  }
}
